@@ -14,10 +14,13 @@
 #' @param file_id the box.com id of the file you'd like to update
 #' @param file A path to a file stored locally
 #' @param dir_id The box.com id for the folder that you'd like to upload to
-#' @return The [httr()] object returned by the api call
+#' @return The [httr::httr()] object returned by the api call
 #' @keywords internal
 #' 
 box_upload_new <- function(dir_id, file, pb = FALSE) {
+  
+  dir_id <- as_box_id(dir_id)
+  
   httr::RETRY(
     "POST",
     "https://upload.box.com/api/2.0/files/content",
@@ -29,7 +32,7 @@ box_upload_new <- function(dir_id, file, pb = FALSE) {
       list(
         attributes = 
           paste0(
-            '{"name": "', basename(file), '", "parent": {"id":"', box_id(dir_id)
+            '{"name": "', basename(file), '", "parent": {"id":"', dir_id
             ,'"}}'
           ),
         file = httr::upload_file(file)
@@ -41,9 +44,13 @@ box_upload_new <- function(dir_id, file, pb = FALSE) {
 #' @rdname box_upload_new
 #' @keywords internal
 box_update_file <- function(file_id, file, dir_id, pb = FALSE) {
+  
+  dir_id <- as_box_id(dir_id)
+  file_id <- as_box_id(file_id)
+  
   httr::RETRY(
     "POST",
-    paste0("https://upload.box.com/api/2.0/files/", box_id(file_id), 
+    paste0("https://upload.box.com/api/2.0/files/", file_id, 
            "/content"),
     get_token(),
     encode = "multipart",
@@ -53,7 +60,7 @@ box_update_file <- function(file_id, file, dir_id, pb = FALSE) {
       list(
         attributes = 
           paste0(
-            '{"name": "', basename(file), '", "parent": {"id":"', box_id(dir_id)
+            '{"name": "', basename(file), '", "parent": {"id":"', dir_id
             ,'"}}'
           ),
         file = httr::upload_file(file)
