@@ -19,7 +19,7 @@
 #' @export
 #' 
 box_source <- function(file_id, local = globalenv(), ...) {
-  temp_dir  <- tempdir()
+  temp_dir  <- withr::local_tempdir()
   temp_file <- box_dl(file_id, overwrite = TRUE, local_dir = temp_dir)
   source(temp_file, local = local, ...)
 }
