@@ -6,13 +6,14 @@
 .onLoad <- function(libname, pkgname) {
   op <- options()
   op.boxr <- list(
-    boxr.token       = NULL,
-    boxr_token_jwt   = NULL,
-    boxr.wd          = list(id = 0, name = "All Files"),
-    boxr.wd.path     = "",
-    boxr.verbose     = TRUE,
-    boxr.progress    = TRUE,
-    boxr.interactive = TRUE
+    boxr.token        = NULL,
+    boxr_token_jwt    = NULL,
+    boxr.wd           = list(id = 0, name = "All Files"),
+    boxr.wd.path      = "",
+    boxr.verbose      = TRUE,
+    boxr.progress     = TRUE,
+    boxr.interactive  = TRUE,
+    boxr.print_tibble = FALSE
   )
   toset <- !(names(op.boxr) %in% names(op))
   if (any(toset)) options(op.boxr[toset])
